==> 0.2.0.tar.gz: lib/ColorSelector/ColorSelectorPage.dart <==
import 'package:dotup_flutter_widgets/dotup_flutter_widgets.dart';
import 'package:flutter/material.dart';

import 'ColorTabView.dart';
import 'ColorTable.dart';

Future<ColorDescriptor?> showColorSelectorPage(BuildContext context) async {
  return Navigator.of(context).push(
    MaterialPageRoute(
      builder: (context) {
        return ColorSelectorPage();
      },
    ),
  );
}

class ColorSelectorPage extends StatefulWidget {
  const ColorSelectorPage({Key? key}) : super(key: key);

  @override
  _ColorSelectorPageState createState() => _ColorSelectorPageState();
}

class _ColorSelectorPageState extends State<ColorSelectorPage> {
  ColorDescriptor? selectedColor;

  @override
  Widget build(BuildContext context) {
    final allColors = ColorTable().palettes;

    return DefaultTabController(
      length: allColors.length,
      child: Scaffold(
        appBar: AppBar(
          actions: [
            IconButton(
              onPressed: () {
                _close(selectedColor);
              },
              icon: Icon(Icons.done),
            ),
          ],
          automaticallyImplyLeading: true,
          title: Text('Farben'),
          bottom: TabBar(
            isScrollable: true,
            // indicator: UnderlineTabIndicator(),
            tabs: [
              for (final palette in allColors) Tab(text: palette.name),
            ],
          ),
        ),
        body: SafeArea(
          child: TabBarView(
            children: [
              for (final palette in allColors)
                ColorTabView(
                  colorPalette: palette,
                  onTap: (value) => selectedColor = value,
                  onDoubleTap: (value) => _close(value),
                ),
            ],
          ),
        ),
      ),
    );
  }

  void _close(ColorDescriptor? selectedColor) {
    Navigator.of(context).pop(selectedColor);
  }
}

==> 0.2.2.tar.gz: lib/ColorSelector/ColorSelectorPage.dart <==
import 'package:dotup_flutter_widgets/dotup_flutter_widgets.dart';
import 'package:flutter/material.dart';

import 'ColorTabView.dart';
import 'ColorTable.dart';

Future<ColorDescriptor?> showColorSelectorPage(BuildContext context) async {
  return Navigator.of(context).push(
    MaterialPageRoute(
      builder: (context) {
        return ColorSelectorPage();
      },
    ),
  );
}

class ColorSelectorPage extends StatefulWidget {
  const ColorSelectorPage({Key? key}) : super(key: key);

  @override
  _ColorSelectorPageState createState() => _ColorSelectorPageState();
}

class _ColorSelectorPageState extends State<ColorSelectorPage> {
  ColorDescriptor? selectedColor;

  @override
  Widget build(BuildContext context) {
    final allColors = ColorTable().palettes;

    return DefaultTabController(
      length: allColors.length,
      child: Scaffold(
        appBar: AppBar(
          actions: [
            IconButton(
              onPressed: () {
                _close(selectedColor);
              },
              icon: Icon(Icons.done),
            ),
          ],
          automaticallyImplyLeading: true,
          title: Text('Farben'),
          bottom: TabBar(
            isScrollable: true,
            // indicator: UnderlineTabIndicator(),
            tabs: [
              for (final palette in allColors) Tab(text: palette.title),
            ],
          ),
        ),
        body: SafeArea(
          child: TabBarView(
            children: [
              for (final palette in allColors)
                ColorTabView(
                  
                  colorPalette: palette,
                  onTap: (value) => selectedColor = value,
                  onDoubleTap: (value) => _close(value),
                ),
            ],
          ),
        ),
      ),
    );
  }

  void _close(ColorDescriptor? selectedColor) {
    Navigator.of(context).pop(selectedColor);
  }
}
